@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.62';
+  $CPAN::Perl::Releases::VERSION = '0.64';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -267,6 +267,10 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.16.0.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.16.0.tar.gz",
   },
+  "5.16.1-RC1" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.1-RC1.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.1-RC1.tar.gz",
+  },
   "5.17.0" => {
     "tar.bz2" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.bz2",
     "tar.gz" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.gz",
@@ -387,7 +391,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.62
+version 0.64
 
 =head1 SYNOPSIS
 
